Detects the format of prediction samples in a data frame.
Examples
if (FALSE) { # \dontrun{
format <- detect_prediction_format(preds)
if (format == "wide") {
preds <- predictions_from_wide(preds)
}
} # }
Detects the format of prediction samples in a data frame.
if (FALSE) { # \dontrun{
format <- detect_prediction_format(preds)
if (format == "wide") {
preds <- predictions_from_wide(preds)
}
} # }