Checks whether a predictions data frame contains sample data (either in nested or wide format).
Examples
if (FALSE) { # \dontrun{
if (has_prediction_samples(preds)) {
preds <- predictions_to_wide(preds)
}
} # }
Checks whether a predictions data frame contains sample data (either in nested or wide format).
if (FALSE) { # \dontrun{
if (has_prediction_samples(preds)) {
preds <- predictions_to_wide(preds)
}
} # }